summaryrefslogtreecommitdiffstats
path: root/Source/cmCableInstantiateClassCommand.cxx
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
committerBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
commitd0a8794746f6de026f1c69652cd09caf8be9cfab (patch)
tree2143ad59bf1fef6f340dd7fb199f556eadff0ef4 /Source/cmCableInstantiateClassCommand.cxx
parente5e2a57bfbf1aac2c265e894db82d2b2d5673084 (diff)
downloadCMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.zip
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.gz
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.bz2
ENH: CABIL -> CABLE rename.
Diffstat (limited to 'Source/cmCableInstantiateClassCommand.cxx')
-rw-r--r--Source/cmCableInstantiateClassCommand.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/Source/cmCableInstantiateClassCommand.cxx b/Source/cmCableInstantiateClassCommand.cxx
index 2491632..ba1f364 100644
--- a/Source/cmCableInstantiateClassCommand.cxx
+++ b/Source/cmCableInstantiateClassCommand.cxx
@@ -13,17 +13,17 @@
See COPYRIGHT.txt for copyright details.
=========================================================================*/
-#include "cmCabilInstantiateClassCommand.h"
+#include "cmCableInstantiateClassCommand.h"
#include "cmCacheManager.h"
#include "cmRegularExpression.h"
/**
* Write the CABIL configuration code to define this InstantiationSet.
* This includes the "class" keyword to do class template instantiations.
*/
-void cmCabilInstantiateClassCommand::WriteConfiguration(std::ostream& os) const
+void cmCableInstantiateClassCommand::WriteConfiguration(std::ostream& os) const
{
cmRegularExpression needCdataBlock("[&<>]");
@@ -13,17 +13,17 @@
#include "cmRegularExpression.h"
/**
- * Write the CABIL configuration code to define this InstantiationSet.
+ * Write the CABLE configuration code to define this InstantiationSet.
* This includes the "class" keyword to do class template instantiations.
*/